/* 
 *  Copyright 2009
 *  Texas Instruments Incorporated
 *
 *  All rights reserved.  Property of Texas Instruments Incorporated
 *  Restricted rights to use, duplicate or disclose this code are
 *  granted through contract.
 * 
 */
/**
 *  @file       ires_algorithm.h 
 *
 *  @brief      Definitions for dummy implementation of the IRES interfaces 
 *              by an algorithm  
 *
 */

#include <ti/xdais/ires.h>
#include <ti/sdo/fc/ires/memtcm/ires_memtcm.h>

/*
 * @brief  Number of resources the algorithm will request 
 */
#define NUM_RESOURCES   2

/*
 * @brief  Number of memory resources required by IALG implementation 
 */
#define NUM_ALLOC       1

/*
 * @brief   IRES interface of the algorithm object
 */
extern IRES_Fxns DUMRES_TI_IRES;

/*
 * @brief   IALG interface of the algorithm object
 */
extern IALG_Fxns DUMRES_TI_IALG;

/*
 *  Implementation of the IALG interface for BUFALG
 */
typedef struct DUMRES_TI_Obj {
    IALG_Obj                    alg;
    IRES_MEMTCM_Handle          resourceHandles[NUM_RESOURCES]; 
    short                       resourceState[NUM_RESOURCES]; 
    IRES_MEMTCM_ProtocolArgs    protocolArgs[NUM_RESOURCES];
    short                       paRamArray[512];
} DUMRES_TI_Obj;

typedef DUMRES_TI_Obj * DUMRES_TI_Handle;
/*
 * Creation paramters for the DUMRES object
 */
typedef struct IDUMRES_Params {
    Int                         size;
    //Int                         memtcm[NUM_RESOURCES];
    Int                         yieldFlag;
    Int                         taskId;
} IDUMRES_Params;

/*
 * Paramter values for DUMRES instance objects 
 */
extern IDUMRES_Params IDUMRES_PARAMS;

/*
 * This structure must be first field of all DUMRES instance objects  
 */
typedef struct IDUMRES_Obj {
    struct IDUMRES_Fxns         *fxns;
} IDUMRES_Obj;

typedef IDUMRES_Obj * IDUMRES_Handle;

/*
 * Defines the full set of operations that can be performed on the DUMRES object
 */
typedef struct IDUMRES_Fxns {
    IALG_Fxns                   alg;
} IDUMRES_Fxns;

/*
 * Defines TI's implementation of the IDUMRES interface 
 */
extern IDUMRES_Fxns DUMRES_TI_IDUMRES;
/*
 *  @(#) ti.sdo.fc.rman.examples.memtcm; 1, 0, 0,23; 11-8-2009 20:58:38; /db/atree/library/trees/fc/fc-l04x/src/
 */

