/* 
 * Copyright (c) 2009, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */
var os = java.lang.System.getProperty("os.name") + "";
var isWin = (os.match(/^Windows/i) != null);
var csd = String(xdc.csd()).replace(/\\/g,"/") + '/';

var thisMod;
var thisPkg;
var thisPkgDir;
var System;

function module$meta$init()
{
    thisPkg     = this.$package;
    thisPkgDir  = csd;
    thisMod     = this;
    System      = xdc.module( thisPkg.$name + ".System" );
}

function getCompilerInfo(algoParams, testSettings, cbPrintLog, detailLevel)
{

    cbPrintLog( "Determining compiler info.\n\n" );

    cbPrintLog( "Chcking if this library was created with a TI compiler...\n" );

    var cgtoolsDir = testSettings.cgtoolsDir + "/";
        var cmd;
    var runResult;

    //noPrintFxn = function() {}; // nothing will be printed
    noPrintFxn = null;

    var isC6x = (algoParams.architecture == "C6x");

    cbPrintLog( "Attempting to determine library format...\n" );

    /* always call checkPath when passing a path to a command */
    var libPath = System.checkPath(algoParams.baseDir + "/" + algoParams.library);

    /* get paths of commands being called */
    var grepPath = System.getCommandPath("grep");
    var ofdPath = System.getCommandPath(cgtoolsDir + "bin/ofd6x");

    // check for COFF or ELF format
    var libFormat = "UNKNOWN";
    var ofd_cmd = ofdPath + " -x --xml_indent=0 --obj_display=none " + libPath;
    var cmd = ofd_cmd + " | " + grepPath + " -E " + "\"<.*coff>|<.*elf>\"";
    runResult = System.runShellCommand( cmd, cbPrintLog, detailLevel);
    if ( runResult.status == 0 ) {
        libFormat = runResult.stdout;
        libFormat = libFormat.match(/^.*/);
        if (libFormat[0].match("elf")) {
            libFormat = "ELF";
        }
        else {
            libFormat = "COFF";
        }
    }

    cbPrintLog( "The library is in " + libFormat + " format.\n\n" );

     /* check for TI compiler */
    if (libFormat == "COFF") {
        /* check by looking for "<ti_coff>" in ofd xml output */
        ofd_cmd = ofdPath + " -x --xml_indent=0 --obj_display=none " + libPath;
        cmd = ofd_cmd + " | " + grepPath + " \"<ti_coff>\"";
        runResult = System.runShellCommand(cmd, cbPrintLog, detailLevel);
        var isTICompiler = (runResult.status == 0);
    }
    else {
        /* check by looking for "Texas Instruments in "DW_AT_producer" */
        ofd_cmd = ofdPath + " -g " + libPath;
        cmd = ofd_cmd + " | " + grepPath + " -A 3 \"DW_AT_producer\"";

        runResult = System.runShellCommand(cmd, cbPrintLog, detailLevel);

        var isTICompiler = (runResult.status == 0 &&
                            runResult.stdout.indexOf("Texas Instruments") != -1);
    }

    cbPrintLog( "This library was " + (isTICompiler ? "" : "not ") + " created with a TI compiler.\n\n" );

    cbPrintLog( "Attempting to determine the compiler version...\n" );

    // check for compiler version using 'strings'/'find' command (linux/windows)
    // TI compilers should contain "Texas Instruments"
    // GCC compilers start with "GCC:"
    var compilerVersion = "UNKNOWN";

    if (isTICompiler) {
        var searchTerm = "\"Texas Instruments\"";
    }
    else {
        searchTerm = "\"GCC:\"";
    }
    /* always call checkPath when passing a path to a command */
    var libPath = System.checkPath(algoParams.baseDir + "/" + algoParams.library);

    if (isWin) {
        var strings_cmd = System.getCommandPath("find") + ' ' + searchTerm;
    }
    else {
        var strings_cmd = System.getCommandPath("strings");
    }
    cmd = strings_cmd + " " + libPath + "|" + System.getCommandPath( "grep" ) +
            " " + searchTerm;

    runResult = System.runShellCommand( cmd, cbPrintLog, detailLevel);

    if ( runResult.status == 0 ) {
        compilerVersion = runResult.stdout;
        compilerVersion = compilerVersion.match(/^.*/); // places each line of stdout in a seperate array index
        compilerVersion = compilerVersion[0];           // grab only the first line that matches
    }

    cbPrintLog( "The compiler is " + compilerVersion + ".\n" );

    return {
        isTICompiler: isTICompiler,
        isC6x: isC6x,
        libFormat: libFormat,
        version: compilerVersion
    };

}
/*
 *  @(#) ti.xdais.qualiti; 1, 0, 0,93; 10-15-2009 13:26:07; /db/wtree/library/trees/dais/dais-q07x/src/
 */

