/* 
 * Copyright (c) 2009, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */
/*!
 *  ======== ACPY3 ========
 *  EDMA3 "Algorithm Copy" library.
 */
@Template("./ACPY3.xdt")

metaonly module ACPY3 {

    /*!
     *  ======= edma3BaseAddress ======= 
     *  EDMA3 Base Address for the device  
     *  Not required to be set if this library    
     *  is used alongwith DMAN3. 
     */
    config UInt edma3BaseAddress;
    
    /*!
     *  ======= paRamBaseAddress ======= 
     *  PaRam Base Address for the device  
     *  Not required to be set if this library    
     *  is used alongwith DMAN3 or for built for TI targets. 
     */
    config UInt paRamBaseAddress;
    
    /*!
     *  ======= nullPaRam ======= 
     *  Index of the paRam to be used as Null paRam 
     *  Not required to be set if this library    
     *  is used alongwith DMAN3. 
     */
    config UInt nullPaRam;
    
    /*!
     *  ======= cpu ========
     *  Builds a non-EDMA, CPU only version of the library   
     */
     config Bool cpu = false;   


    /*!
     *  ======== debug ========
     *  Enable the debug profile of the ACPY3 library.
     *
     *  This will result in a larger and slower library being linked in,
     *  but it will provide extra parameter checking to ensure callers are
     *  meeting the API requirements.
     *
     *  If these API requirements are not met, SYS_abort() will be called.
     *  @_nodoc
     */
    config bool debug = false;

    /*!
     *  ======== trace ========
     *  Enable trace in the ACPY3 library.
     *
     *  This will result in a larger and slower library being linked in,
     *  but it will provide trace statements for debugging purposes.
     *  @_nodoc
     */
    config bool trace = false;

    /*!
     *  ======== instrumented ========
     *  Enable instrumentation in the ACPY3 library.
     */
    config bool instrumented = false;
}

/*
 *  @(#) ti.sdo.fc.acpy3; 1, 0, 4,279; 11-8-2009 20:57:19; /db/atree/library/trees/fc/fc-l04x/src/
 */

