/* 
 * Copyright (c) 2009, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */
/*
 *  ======== dman3_initImpl.c ========
 *  Initialize the DMAN3 module
 */

#include <xdc/std.h>

#ifdef xdc_target__isaCompatible_64P
#include <ti/bios/include/mem.h>
#include <ti/sdo/fc/utils/dbc.h>
#else
#include "bios_rts.h"
#endif

#include <string.h> /* For memset() */

#include "dman3.h"
#include "dman3_impl.h"

#include <ti/sdo/utils/trace/gt.h>
extern GT_Mask ti_sdo_fc_dman3_GTMask;

#ifdef xdc_target__isaCompatible_64P
#pragma CODE_SECTION(_DMAN3_initImpl, ".text:DMAN3_init");
#endif

static Int      heapInt;
static Int      heapExt;
static Int      refCount = 0;

/*
 *  ======== _DMAN3_initImpl ========
 *  Initialize the DMAN module
 */
Void _DMAN3_initImpl(Void)
{
    if (refCount == 0) {
        GT_init();
        GT_create(&ti_sdo_fc_dman3_GTMask, DMAN3_GTNAME);
    }

    GT_0trace(ti_sdo_fc_dman3_GTMask, GT_ENTER, "_DMAN3_initImpl> Enter\n");

    if (refCount++ == 0) {
        heapInt = DMAN3_PARAMS.heapInternal;
        heapExt = DMAN3_PARAMS.heapExternal;

        heapInt = (heapInt == -1) ? heapExt : heapInt;
        heapExt = (heapExt == -1) ? heapInt : heapExt;

        /* This is a fatal configuration error. */
        DBC_assert(heapInt != -1);
        GT_assert(ti_sdo_fc_dman3_GTMask, heapInt != -1);

    }

    GT_0trace(ti_sdo_fc_dman3_GTMask, GT_ENTER, "_DMAN3_initImpl> Exit\n");
}

/*
 *  ======== DMAN3_exit ========
 *  Finalization method of the DMAN3 module
 */
Void DMAN3_exit(Void)
{
    GT_0trace(ti_sdo_fc_dman3_GTMask, GT_ENTER, "DMAN3_exit> Enter\n");

    --refCount;

    GT_exit();
}

/*
 *  @(#) ti.sdo.fc.dman3; 1, 0, 4,278; 11-8-2009 20:57:21; /db/atree/library/trees/fc/fc-l04x/src/
 */

